@@ -13,7 +13,7 @@ from numbers import Number
 from collections import defaultdict
 from random import choice, random, shuffle
 from enum import Enum
-from hilbert_curve import hilbert
+from hilbertcurve.hilbertcurve import HilbertCurve
 
 
 class Colors(Enum):
@@ -69,8 +69,9 @@ class Aceto(object):
         code_helper = defaultdict(lambda: defaultdict(str))
         chars = "".join(char for line in fileobj for char in line.strip())
         p = (ceil(len(chars) ** 0.5) - 1).bit_length()
+        hilbert = HilbertCurve(p, 2)
         for step, char in enumerate(chars):
-            y, x = hilbert.coordinates_from_distance(step, p, N=2,)
+            y, x = hilbert.coordinates_from_distance(step)
             code_helper[x][y] = char
         return code_helper, p
 
@@ -79,7 +80,7 @@ class Aceto(object):
         code = []
         for line in reversed(fileobj.readlines()):
             code.append(list(line.rstrip("\n")))
-        return code, (max(len(code), max(map(len, code)),) - 1).bit_length()
+        return code, (max(len(code), max(map(len, code))) - 1).bit_length()
 
     def load_code(self, filename, linear_mode=False):
         with open(filename, encoding=self.encoding) as f:
@@ -95,6 +96,7 @@ class Aceto(object):
         self.buf = ""
         self.mode = "command"
         self.previous_cmd = " "
+        self.hilbert = HilbertCurve(self.p, 2)  # side length p, 2 dimensions
 
     def run(self):
         while True:
@@ -130,8 +132,8 @@ class Aceto(object):
 
     def next_coord(self):
         """Return the next coordinate"""
-        distance = hilbert.distance_from_coordinates([self.y, self.x], self.p, N=2,)
-        y, x = hilbert.coordinates_from_distance(distance + self.dir, self.p, N=2,)
+        distance = self.hilbert.distance_from_coordinates([self.y, self.x])
+        y, x = self.hilbert.coordinates_from_distance(distance + self.dir)
         return x, y
 
     def step_command_mode(self, cmd):
@@ -198,7 +200,10 @@ class Aceto(object):
             if self.dir == -1 and (0, 0) == (self.x, self.y):
                 x, y = -1, -1
             else:
-                x, y = self.next_coord()
+                try:
+                    x, y = self.next_coord()
+                except ValueError:
+                    sys.exit()
         if x >= 2 ** self.p or y >= 2 ** self.p or x < 0 or y < 0:
             sys.exit()
         self.x, self.y = x, y
@@ -480,9 +485,7 @@ class Aceto(object):
         cond = self.pop()
         if cond:
             new_pos = (self.x, 2 ** self.p - (self.y + 1))
-            self.log(
-                2, "Mirroring horizontally from", self.x, self.y, "to", new_pos,
-            )
+            self.log(2, "Mirroring horizontally from", self.x, self.y, "to", new_pos)
             self.move(new_pos)
         else:
             self.move()
@@ -491,9 +494,7 @@ class Aceto(object):
         cond = self.pop()
         if cond:
             new_pos = (2 ** self.p - (self.x + 1), self.y)
-            self.log(
-                2, "Mirroring vertically from", self.x, self.y, "to", new_pos,
-            )
+            self.log(2, "Mirroring vertically from", self.x, self.y, "to", new_pos)
             self.move(new_pos)
         else:
             self.move()
@@ -604,16 +605,14 @@ class Aceto(object):
 
     def _jump(self, cmd) -> "j":
         steps = self.pop()
-        distance = hilbert.distance_from_coordinates([self.y, self.x], self.p, N=2,)
-        y, x = hilbert.coordinates_from_distance(
-            distance + self.dir * steps, self.p, N=2,
-        )
+        distance = self.hilbert.distance_from_coordinates([self.y, self.x])
+        y, x = self.hilbert.coordinates_from_distance(distance + self.dir * steps)
         self.x, self.y = x, y
 
     def _goto(self, cmd) -> "§":
         distance = self.pop()
         # TODO: should take the direction (self.dir) into account.
-        y, x = hilbert.coordinates_from_distance(distance, self.p, N=2)
+        y, x = self.hilbert.coordinates_from_distance(distance)
         self.x, self.y = x, y
 
     def _join(self, cmd) -> "J":
@@ -800,22 +799,6 @@ def getch():
     return ch
 
 
-"""
-Aceto - A language based on 2D hilbert curve grids
-
-Usage:
-    aceto.py [-v ...] [options] [<filename> ...]
-
-Options:
-    -v --verbose       Be verbose. Can be specified several times.
-    -F --flush         Always flush after printing.
-    -e --err-all       Ignore catch marks (@) and always error out
-    -w --windows-1252  Use Windows-1252 instead of UTF-8 (deprecated)
-    -g --latin-7       Use Latin-7 instead of UTF-8
-    -l --linear        Use linear mode for text entry
-"""
-
-
 @click.command()
 @click.argument("files", type=click.Path(), nargs=-1)
 @click.option("--verbose", "-v", count=True)
